@@ -21,8 +21,10 @@
 #define KDECLARATIVE_P_H
 
 #include "kdeclarative.h"
+#include "qmlobject.h"
 
 #include <QtCore/QPointer>
+#include <KLocalizedContext>
 
 namespace KDeclarative {
 
@@ -32,8 +34,10 @@ public:
     KDeclarativePrivate();
 
     QPointer<QQmlEngine> declarativeEngine;
-    bool initialized;
+    QString translationDomain;
     static QStringList s_runtimePlatform;
+    QPointer<KLocalizedContext> contextObj;
+    QPointer<QmlObject> qmlObj;
 };
 
 }
